@@ -3,10 +3,20 @@
  *
  * This file is part of GPA.
  *
- * GPA is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * GPA is free software; you can redistribute and/or modify this part
+ * of GPA under the terms of either
+ *
+ *   - the GNU Lesser General Public License as published by the Free
+ *     Software Foundation; either version 3 of the License, or (at
+ *     your option) any later version.
+ *
+ * or
+ *
+ *   - the GNU General Public License as published by the Free
+ *     Software Foundation; either version 2 of the License, or (at
+ *     your option) any later version.
+ *
+ * or both in parallel, as here.
  *
  * GPA is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -14,7 +24,7 @@
  * License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>. 
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +36,7 @@
 #include <string.h>
 #include <assert.h>
 
-#include "gpa.h"   
+#include "gpa.h"
 #include "gtktools.h"
 #include "convert.h"
 #include "gpa-key-details.h"
@@ -49,7 +59,7 @@ enum
     ENTRY_SIGG_PUK_RETRYCOUNTER,
 
     ENTRY_LAST
-  }; 
+  };
 
 
 /* A structure for PIN information.  */
@@ -65,7 +75,7 @@ struct pininfo_s
 
 
 /* Object's class definition.  */
-struct _GpaCMNetkeyClass 
+struct _GpaCMNetkeyClass
 {
   GpaCMObjectClass parent_class;
 };
@@ -106,7 +116,7 @@ static void gpa_cm_netkey_finalize (GObject *object);
 
 
 
-/************************************************************ 
+/************************************************************
  *******************   Implementation   *********************
  ************************************************************/
 
@@ -127,13 +137,13 @@ clear_card_data (GpaCMNetkey *card)
 /* Put the PIN information into the field with ENTRY_ID.  If BUTTON is
    not NULL its sensitivity is set as well. */
 static void
-update_entry_retry_counter (GpaCMNetkey *card, int entry_id, 
+update_entry_retry_counter (GpaCMNetkey *card, int entry_id,
                             struct pininfo_s *info, int any_isnull,
                             int is_puk, GtkWidget *button)
 {
   char numbuf[50];
   const char *string;
-  
+
   if (!info->valid)
     string = _("unknown");
   else if (info->nullpin)
@@ -150,12 +160,12 @@ update_entry_retry_counter (GpaCMNetkey *card, int entry_id,
   gtk_label_set_text (GTK_LABEL (card->entries[entry_id]), string);
   if (button)
     {
-      gtk_button_set_label (GTK_BUTTON (button), 
+      gtk_button_set_label (GTK_BUTTON (button),
                             (info->valid && !info->nullpin
                              && (info->blocked || !info->tries_left))
                             ? (is_puk? _("Reset PUK") : _("Reset PIN"))
                             : (is_puk? _("Change PUK"): _("Change PIN")));
-      gtk_widget_set_sensitive (button, 
+      gtk_widget_set_sensitive (button,
                                 (info->valid && !any_isnull
                                  && !info->nullpin && !info->blocked
                                  && !info->nopin));
@@ -168,12 +178,12 @@ update_entry_retry_counter (GpaCMNetkey *card, int entry_id,
 static void
 update_entry_chv_status (GpaCMNetkey *card, int entry_id, char *string)
 {
-  struct { 
+  struct {
     int info_idx;
     int is_puk;
     int entry_id;
     GtkWidget *widget;
-  } tbl[] = 
+  } tbl[] =
     {
       {  0, 0, ENTRY_PIN_RETRYCOUNTER },
       {  1, 1, ENTRY_PUK_RETRYCOUNTER  },
@@ -190,7 +200,7 @@ update_entry_chv_status (GpaCMNetkey *card, int entry_id, char *string)
   tbl[3].widget = card->change_sigg_puk_btn;
 
   (void)entry_id; /* Not used.  */
-  
+
   for (idx=0; idx < DIM (card->pininfo); idx++)
     memset (&card->pininfo[idx], 0, sizeof card->pininfo[0]);
 
@@ -203,7 +213,7 @@ update_entry_chv_status (GpaCMNetkey *card, int entry_id, char *string)
         string++;
       while (spacep (string))
         string++;
-      
+
       card->pininfo[idx].valid = 1;
       if (value >= 0)
         card->pininfo[idx].tries_left = value;
@@ -224,7 +234,7 @@ update_entry_chv_status (GpaCMNetkey *card, int entry_id, char *string)
     if (tbl[idx].info_idx < DIM (card->pininfo))
       update_entry_retry_counter (card, tbl[idx].entry_id,
                                   &card->pininfo[tbl[idx].info_idx],
-                                  any_isnull, 
+                                  any_isnull,
                                   tbl[idx].is_puk, tbl[idx].widget);
 
   gtk_widget_set_no_show_all (card->warning_frame, FALSE);
@@ -262,9 +272,11 @@ reload_more_data_cb (void *opaque, const char *status, const char *args)
   const char *keyid;
   int any = 0;
 
+  g_debug ("  reload_more_data (%s=%s)", status, args);
   if (strcmp (status, "KEYPAIRINFO") )
     return 0;
 
+  g_debug ("   start search");
   idx = 0;
   pattern[idx++] = '&';
   for (s=args; hexdigitp (s) && idx < sizeof pattern - 1; s++)
@@ -308,6 +320,7 @@ reload_more_data_cb (void *opaque, const char *status, const char *args)
   gpgme_op_keylist_end (parm->ctx);
   if (!any)
     parm->any_unknown = 1;
+  g_debug ("   ready");
   return 0;
 }
 
@@ -316,14 +329,16 @@ reload_more_data_cb (void *opaque, const char *status, const char *args)
 static void
 reload_more_data (GpaCMNetkey *card)
 {
-  gpg_error_t err;
+  gpg_error_t err, operr;
   gpgme_ctx_t gpgagent;
   GtkWidget *vbox;
   struct reload_more_data_parm parm;
 
+  g_debug ("start reload_more_data (count=%d)", card->reloading);
   gpgagent = GPA_CM_OBJECT (card)->agent_ctx;
   g_return_if_fail (gpgagent);
   g_return_if_fail (card->keys_frame);
+  g_debug ("  gpgagent=%p", gpgagent);
 
   /* We remove any existing children of the keys frame and then we add
      a new vbox to be filled with new widgets by the callback.  */
@@ -348,12 +363,16 @@ reload_more_data (GpaCMNetkey *card)
   /* We include ephemeral keys in the listing.  */
   gpgme_set_keylist_mode (parm.ctx, GPGME_KEYLIST_MODE_EPHEMERAL);
 
-  err = gpgme_op_assuan_transact (gpgagent,
-                                  "SCD LEARN --keypairinfo",
-                                  NULL, NULL, NULL, NULL,
-                                  reload_more_data_cb, &parm);
+  g_debug ("  parm.ctx=%p", parm.ctx);
+
+  err = gpgme_op_assuan_transact_ext (gpgagent,
+                                      "SCD LEARN --keypairinfo",
+                                      NULL, NULL, NULL, NULL,
+                                      reload_more_data_cb, &parm, &operr);
+  g_debug ("  assuan ret=%d", err);
   if (!err)
-    err = gpgme_op_assuan_result (gpgagent)->err;
+    err = operr;
+
   if (err)
     g_debug ("SCD LEARN failed: %s", gpg_strerror (err));
 
@@ -363,7 +382,7 @@ reload_more_data (GpaCMNetkey *card)
 
       align = gtk_alignment_new (0.5, 0, 0, 0);
       button = gtk_button_new_with_label (_("Learn keys"));
-      gpa_add_tooltip 
+      gpa_add_tooltip
         (button, _("For some or all of the keys available on the card, "
                    "the GnuPG crypto engine does not yet know the "
                    "corresponding certificates.\n"
@@ -386,6 +405,7 @@ reload_more_data (GpaCMNetkey *card)
 
   gpgme_release (parm.ctx);
   gtk_widget_show_all (card->keys_frame);
+  g_debug ("end   reload_more_data (count=%d)", card->reloading);
   return;
 }
 
@@ -395,14 +415,17 @@ static gboolean
 reload_more_data_idle_cb (void *user_data)
 {
   GpaCMNetkey *card = user_data;
-  
+
   if (card->reloading)
+    {
+      g_debug ("already reloading (count=%d)", card->reloading);
     return TRUE; /* Just in case we are still reloading, wait for the
                     next idle slot.  */
+    }
 
   card->reloading++;
   reload_more_data (card);
-  g_object_unref (card); 
+  g_object_unref (card);
   card->reloading--;
 
   return FALSE;  /* Remove us from the idle queue.  */
@@ -438,17 +461,17 @@ scd_getattr_cb (void *opaque, const char *status, const char *args)
           if (parm->updfnc)
             parm->updfnc (parm->card, entry_id, tmp);
           else if (GTK_IS_LABEL (parm->card->entries[entry_id]))
-            gtk_label_set_text 
+            gtk_label_set_text
               (GTK_LABEL (parm->card->entries[entry_id]), tmp);
           else
-            gtk_entry_set_text 
+            gtk_entry_set_text
               (GTK_ENTRY (parm->card->entries[entry_id]), tmp);
           xfree (tmp);
         }
     }
 
   return 0;
-}     
+}
 
 
 /* Use the assuan machinery to load the bulk of the OpenPGP card data.  */
@@ -467,6 +490,7 @@ reload_data (GpaCMNetkey *card)
   };
   int attridx;
   gpg_error_t err = 0;
+  gpg_error_t operr;
   char command[100];
   struct scd_getattr_parm parm;
   gpgme_ctx_t gpgagent;
@@ -475,6 +499,7 @@ reload_data (GpaCMNetkey *card)
   g_return_if_fail (gpgagent);
 
   card->reloading++;
+  g_debug ("uped reloading counter (count=%d)", card->reloading);
 
   /* Show all attributes.  */
   parm.card = card;
@@ -484,19 +509,19 @@ reload_data (GpaCMNetkey *card)
       parm.entry_id = attrtbl[attridx].entry_id;
       parm.updfnc   = attrtbl[attridx].updfnc;
       snprintf (command, sizeof command, "SCD GETATTR %s", parm.name);
-      err = gpgme_op_assuan_transact (gpgagent,
-                                      command,
-                                      NULL, NULL,
-                                      NULL, NULL,
-                                      scd_getattr_cb, &parm);
+      err = gpgme_op_assuan_transact_ext (gpgagent,
+                                          command,
+                                          NULL, NULL,
+                                          NULL, NULL,
+                                          scd_getattr_cb, &parm, &operr);
       if (!err)
-        err = gpgme_op_assuan_result (gpgagent)->err;
+        err = operr;
 
       if (err && attrtbl[attridx].entry_id == ENTRY_NKS_VERSION)
         {
           /* The NKS-VERSION is only supported by GnuPG > 2.0.11
              thus we ignore the error.  */
-          gtk_label_set_text 
+          gtk_label_set_text
             (GTK_LABEL (card->entries[attrtbl[attridx].entry_id]),
              _("unknown"));
         }
@@ -506,7 +531,7 @@ reload_data (GpaCMNetkey *card)
             ; /* Lost the card.  */
           else
             {
-              g_debug ("assuan command `%s' failed: %s <%s>\n", 
+              g_debug ("assuan command `%s' failed: %s <%s>\n",
                        command, gpg_strerror (err), gpg_strsource (err));
             }
           clear_card_data (card);
@@ -519,11 +544,12 @@ reload_data (GpaCMNetkey *card)
       g_idle_add (reload_more_data_idle_cb, card);
     }
   card->reloading--;
+  g_debug ("downed reloading counter (count=%d)", card->reloading);
 }
 
 
 /* A structure used to pass data to the learn_keys_gpg_status_cb.  */
-struct learn_keys_gpg_status_parm 
+struct learn_keys_gpg_status_parm
 {
   GpaCMNetkey    *card;
   GtkWidget      *button;
@@ -532,11 +558,11 @@ struct learn_keys_gpg_status_parm
 
 
 /* Helper for learn_keys_clicked_cb.  */
-static gboolean 
+static gboolean
 learn_keys_gpg_status_cb (void *opaque, char *line)
 {
   struct learn_keys_gpg_status_parm *parm = opaque;
-  
+
   if (!line)
     {
       /* We are finished with the command.  */
@@ -576,7 +602,7 @@ learn_keys_clicked_cb (GtkButton *button, void *user_data)
 
   widget = gtk_progress_bar_new ();
   gtk_container_add (GTK_CONTAINER (button), widget);
-  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), 
+  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget),
                               _("Learning keys ..."));
   gtk_widget_show_all (GTK_WIDGET (button));
 
@@ -586,8 +612,8 @@ learn_keys_clicked_cb (GtkButton *button, void *user_data)
   parm->button = GTK_WIDGET (button);
   parm->pbar = GTK_PROGRESS_BAR (widget);
 
-  err = gpa_start_simple_gpg_command 
-    (learn_keys_gpg_status_cb, parm, GPGME_PROTOCOL_CMS,
+  err = gpa_start_simple_gpg_command
+    (learn_keys_gpg_status_cb, parm, GPGME_PROTOCOL_CMS, 1,
      "--learn-card", "-v", NULL);
   if (err)
     {
@@ -602,7 +628,7 @@ learn_keys_clicked_cb (GtkButton *button, void *user_data)
 static void
 change_nullpin (GpaCMNetkey *card)
 {
-  gpg_error_t err;
+  gpg_error_t err, operr;
   GtkWidget *dialog;
   gpgme_ctx_t gpgagent;
   int is_sigg;
@@ -619,14 +645,14 @@ change_nullpin (GpaCMNetkey *card)
   else
     return; /* Oops: No NullPIN.  */
 
-  string = g_strdup_printf 
+  string = g_strdup_printf
     (_("<b>Setting the Initial PIN</b> (%s)\n\n"
        "You selected to set the initial PIN of your card.  "
        "The PIN is currently set to the NullPIN.  Setting an "
        "initial PIN is <b>required but can't be reverted</b>.\n\n"
        "Please check the documentation of your card to learn "
        "for what the NullPIN is good.\n\n"
-       "If you proceeed you will be asked to enter a new PIN "
+       "If you proceed you will be asked to enter a new PIN "
        "and later to repeat that PIN.  Make sure that you "
        "will remember that PIN - it will not be possible to "
        "recover the PIN if it has been entered wrongly more "
@@ -639,12 +665,12 @@ change_nullpin (GpaCMNetkey *card)
          "PIN to the same value as used for the NKS keys.")
      : _("You are now setting the PIN for the NKS keys used for standard "
          "signatures, encryption and authentication."));
-    
+
   /* FIXME:  How do we figure out our GtkWindow?  */
   dialog = gtk_message_dialog_new_with_markup (NULL /*GTK_WINDOW (card)*/,
                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                               GTK_MESSAGE_INFO, 
-                                               GTK_BUTTONS_OK_CANCEL, 
+                                               GTK_MESSAGE_INFO,
+                                               GTK_BUTTONS_OK_CANCEL,
                                                NULL);
   gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), string);
   g_free (string);
@@ -652,20 +678,21 @@ change_nullpin (GpaCMNetkey *card)
   okay = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK);
   if (okay)
     {
-      err = gpgme_op_assuan_transact (gpgagent,
-                                      is_sigg
-                                      ? "SCD PASSWD --nullpin PW1.CH.SIG"
-                                      : "SCD PASSWD --nullpin PW1.CH",
-                                      NULL, NULL,
-                                      NULL, NULL,
-                                      NULL, NULL);
+      err = gpgme_op_assuan_transact_ext (gpgagent,
+                                          is_sigg
+                                          ? "SCD PASSWD --nullpin PW1.CH.SIG"
+                                          : "SCD PASSWD --nullpin PW1.CH",
+                                          NULL, NULL,
+                                          NULL, NULL,
+                                          NULL, NULL, &operr);
       if (!err)
-        err = gpgme_op_assuan_result (gpgagent)->err;
+        err = operr;
+
       if (gpg_err_code (err) == GPG_ERR_CANCELED)
         okay = 0; /* No need to reload the data.  */
       else if (err)
         {
-          char *message = g_strdup_printf 
+          char *message = g_strdup_printf
             (_("Error changing the NullPIN.\n"
                "(%s <%s>)"), gpg_strerror (err), gpg_strsource (err));
           gpa_window_error (message, NULL);
@@ -682,7 +709,7 @@ change_nullpin (GpaCMNetkey *card)
 static void
 change_or_reset_pin (GpaCMNetkey *card, int info_idx)
 {
-  gpg_error_t err;
+  gpg_error_t err, operr;
   GtkWidget *dialog;
   gpgme_ctx_t gpgagent;
   int reset_mode;
@@ -695,7 +722,7 @@ change_or_reset_pin (GpaCMNetkey *card, int info_idx)
   g_return_if_fail (gpgagent);
   g_return_if_fail (info_idx < DIM (card->pininfo));
 
-  if (!card->pininfo[info_idx].valid 
+  if (!card->pininfo[info_idx].valid
       || card->pininfo[info_idx].nopin
       || card->pininfo[info_idx].nullpin)
     {
@@ -727,7 +754,7 @@ change_or_reset_pin (GpaCMNetkey *card, int info_idx)
                 "of the PIN and the corresponding PUK are both down "
                 "to zero, the keys controlled by the PIN are not anymore "
                 "usable and there is no way to unblock them!")
-            : is_puk 
+            : is_puk
             ? _("<b>Resetting a PUK</b>\n"
                 "\n"
                 "Although <i>PUK</i> stands for <i>PIN Unblocking Code</i> "
@@ -752,12 +779,12 @@ change_or_reset_pin (GpaCMNetkey *card, int info_idx)
                 "value of the PUK and then to enter a new value for the "
                 "blocked PIN and repeat that new value at another prompt.")
             );
-              
+
   /* FIXME:  How do we figure out our GtkWindow?  */
   dialog = gtk_message_dialog_new_with_markup (NULL /*GTK_WINDOW (card)*/,
                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                               GTK_MESSAGE_INFO, 
-                                               GTK_BUTTONS_OK_CANCEL, 
+                                               GTK_MESSAGE_INFO,
+                                               GTK_BUTTONS_OK_CANCEL,
                                                NULL);
   gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), string);
   okay = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK);
@@ -767,15 +794,17 @@ change_or_reset_pin (GpaCMNetkey *card, int info_idx)
 
       snprintf (command, sizeof command, "SCD PASSWD%s %s",
                 reset_mode? " --reset":"", pwidstr);
-      err = gpgme_op_assuan_transact (gpgagent, command,
-                                      NULL, NULL, NULL, NULL, NULL, NULL);
-      if (!err) 
-        err = gpgme_op_assuan_result (gpgagent)->err;
+      err = gpgme_op_assuan_transact_ext (gpgagent, command,
+                                          NULL, NULL, NULL, NULL, NULL, NULL,
+                                          &operr);
+      if (!err)
+        err = operr;
+
       if (gpg_err_code (err) == GPG_ERR_CANCELED)
         okay = 0; /* No need to reload the data.  */
-      else if (err) 
+      else if (err)
         {
-          char *message = g_strdup_printf 
+          char *message = g_strdup_printf
             (_("Error changing or resetting the PIN/PUK.\n"
                "(%s <%s>)"), gpg_strerror (err), gpg_strsource (err));
           gpa_window_error (message, NULL);
@@ -826,12 +855,12 @@ add_table_row (GtkWidget *table, int *rowidx,
   label = gtk_label_new (labelstr);
   gtk_label_set_width_chars  (GTK_LABEL (label), 22);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1,	       
-                    *rowidx, *rowidx + 1, GTK_FILL, GTK_SHRINK, 0, 0); 
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1,
+                    *rowidx, *rowidx + 1, GTK_FILL, GTK_SHRINK, 0, 0);
 
   if (is_label)
     gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
-  
+
   if (readonly)
     {
       if (!is_label && GTK_IS_ENTRY (widget))
@@ -845,7 +874,7 @@ add_table_row (GtkWidget *table, int *rowidx,
       if (is_label)
         gtk_label_set_selectable (GTK_LABEL (widget), TRUE);
     }
-      
+
   gtk_table_attach (GTK_TABLE (table), widget, 1, 2,
                     *rowidx, *rowidx + 1, GTK_FILL, GTK_SHRINK, 0, 0);
   if (widget2)
@@ -879,17 +908,17 @@ construct_data_widget (GpaCMNetkey *card)
   gtk_container_set_border_width (GTK_CONTAINER (table), 10);
   gtk_container_add (GTK_CONTAINER (frame), table);
   rowidx = 0;
-  
+
   card->entries[ENTRY_SERIALNO] = gtk_label_new (NULL);
   add_table_row (table, &rowidx, _("Serial number:"),
                  card->entries[ENTRY_SERIALNO], NULL, 0);
 
   card->entries[ENTRY_NKS_VERSION] = gtk_label_new (NULL);
-  add_table_row (table, &rowidx, _("Card version:"), 
+  add_table_row (table, &rowidx, _("Card version:"),
                  card->entries[ENTRY_NKS_VERSION], NULL, 0);
 
   gtk_box_pack_start (GTK_BOX (card), frame, FALSE, TRUE, 0);
-  
+
 
   /* Warning frame.  */
   frame = gtk_frame_new (NULL);
@@ -925,7 +954,7 @@ construct_data_widget (GpaCMNetkey *card)
      widgets are added while figuring out the keys of the card.  */
   label = gtk_label_new (_("scanning ..."));
   gtk_container_add (GTK_CONTAINER (frame), label);
-  
+
   gtk_box_pack_start (GTK_BOX (card), frame, FALSE, TRUE, 0);
   card->keys_frame = frame;
 
@@ -943,42 +972,42 @@ construct_data_widget (GpaCMNetkey *card)
 
   card->entries[ENTRY_PIN_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
-  add_table_row (table, &rowidx, _("PIN retry counter:"), 
+  add_table_row (table, &rowidx, _("PIN retry counter:"),
                  card->entries[ENTRY_PIN_RETRYCOUNTER], button, 1);
-  card->change_pin_btn = button; 
+  card->change_pin_btn = button;
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (change_pin_clicked_cb), card);
 
   card->entries[ENTRY_PUK_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
-  add_table_row (table, &rowidx, _("PUK retry counter:"), 
+  add_table_row (table, &rowidx, _("PUK retry counter:"),
                  card->entries[ENTRY_PUK_RETRYCOUNTER], button, 1);
-  card->change_puk_btn = button; 
+  card->change_puk_btn = button;
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (change_pin_clicked_cb), card);
 
   card->entries[ENTRY_SIGG_PIN_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
-  add_table_row (table, &rowidx, _("SigG PIN retry counter:"), 
+  add_table_row (table, &rowidx, _("SigG PIN retry counter:"),
                  card->entries[ENTRY_SIGG_PIN_RETRYCOUNTER], button, 1);
-  card->change_sigg_pin_btn = button; 
+  card->change_sigg_pin_btn = button;
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (change_pin_clicked_cb), card);
 
   card->entries[ENTRY_SIGG_PUK_RETRYCOUNTER] = gtk_label_new (NULL);
   button = gtk_button_new ();
-  add_table_row (table, &rowidx, _("SigG PUK retry counter:"), 
+  add_table_row (table, &rowidx, _("SigG PUK retry counter:"),
                  card->entries[ENTRY_SIGG_PUK_RETRYCOUNTER], button, 1);
-  card->change_sigg_puk_btn = button; 
+  card->change_sigg_puk_btn = button;
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (change_pin_clicked_cb), card);
-  
+
   gtk_box_pack_start (GTK_BOX (card), frame, FALSE, TRUE, 0);
 }
 
 
 
-/************************************************************ 
+/************************************************************
  ******************   Object Management  ********************
  ************************************************************/
 
@@ -988,7 +1017,7 @@ gpa_cm_netkey_class_init (void *class_ptr, void *class_data)
   GpaCMNetkeyClass *klass = class_ptr;
 
   parent_class = g_type_class_peek_parent (klass);
-  
+
   G_OBJECT_CLASS (klass)->finalize = gpa_cm_netkey_finalize;
 }
 
@@ -1005,7 +1034,7 @@ gpa_cm_netkey_init (GTypeInstance *instance, void *class_ptr)
 
 static void
 gpa_cm_netkey_finalize (GObject *object)
-{  
+{
 /*   GpaCMNetkey *card = GPA_CM_NETKEY (object); */
 
   parent_class->finalize (object);
@@ -1017,7 +1046,7 @@ GType
 gpa_cm_netkey_get_type (void)
 {
   static GType this_type = 0;
-  
+
   if (!this_type)
     {
       static const GTypeInfo this_info =
@@ -1032,23 +1061,23 @@ gpa_cm_netkey_get_type (void)
 	  0,    /* n_preallocs */
 	  gpa_cm_netkey_init
 	};
-      
+
       this_type = g_type_register_static (GPA_CM_OBJECT_TYPE,
                                           "GpaCMNetkey",
                                           &this_info, 0);
     }
-  
+
   return this_type;
 }
 
 
-/************************************************************ 
+/************************************************************
  **********************  Public API  ************************
  ************************************************************/
 GtkWidget *
 gpa_cm_netkey_new ()
 {
-  return GTK_WIDGET (g_object_new (GPA_CM_NETKEY_TYPE, NULL));  
+  return GTK_WIDGET (g_object_new (GPA_CM_NETKEY_TYPE, NULL));
 }
 
 
