@@ -34,6 +34,7 @@
 #include "gpgmetools.h"
 #include "gtktools.h"
 #include "options.h"
+#include "gpa.h"
 
 /* Violation of GNOME standards: Cancel does not revert previous
    apply.  We do not auto-apply or syntax check after focus
@@ -970,12 +971,16 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 
       if (reset)
 	{
+	  char *description;
 	  /* FIXME: Might need to put pages into scrolled panes if
 	     there are too many.  */
 	  page = gtk_vbox_new (FALSE, 0);
 	  gtk_container_add (GTK_CONTAINER (dialog_notebook), page);
 
-	  label = gtk_label_new (comp->description);
+	  description = xstrdup (comp->description);
+	  percent_unescape (description, 0);
+	  label = gtk_label_new (description);
+	  xfree (description);
 	  gtk_notebook_set_tab_label
 	    (GTK_NOTEBOOK (dialog_notebook),
 	     gtk_notebook_get_nth_page (GTK_NOTEBOOK (dialog_notebook),
@@ -1012,7 +1017,8 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 	{
 	  if (option->flags & GPGME_CONF_GROUP)
 	    {
-	      char name[80];
+	      char *name;
+	      const char *title;
 
 	      if (! group_has_options (option, &option))
 		continue;
@@ -1027,11 +1033,12 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
                  used for it.  AFAICS, we would only need to prefix
                  the description with the group name and gpgconf would
                  instantly privide that. */
-	      snprintf (name, sizeof (name), "<b>%s</b>",
-                        (option->argname && *option->argname)?
-                         option->argname : option->description);
-	      name[sizeof (name) - 1] = '\0';
+	      title = (option->argname && *option->argname)?
+			option->argname : option->description;
+	      name = g_strdup_printf ("<b>%s</b>", title);
+	      percent_unescape (name, 0);
 	      label = gtk_label_new (name);
+	      xfree (name);
 
 	      gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	      gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -1192,7 +1199,13 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 #if GTK_CHECK_VERSION (2, 12, 0)
 	      /* Add a tooltip description.  */
 	      if (option->description)
-		gtk_widget_set_tooltip_text (vbox, option->description);
+		{
+		  char *description = xstrdup (option->description);
+
+	          percent_unescape (description, 0);
+		  gtk_widget_set_tooltip_text (vbox, description);
+		  xfree (description);
+		}
 #endif
 	    }
 	  option = option->next;
@@ -1601,8 +1614,8 @@ gpa_configure_keyserver (GtkWidget *parent)
   keyserver = gpa_load_configured_keyserver ();
   if (!keyserver)
     {
-      gpa_show_warning
-        (parent, _("Configuring the backend to use a keyserver failed"));
+      gpa_show_warn
+        (parent, NULL, _("Configuring the backend to use a keyserver failed"));
       return NULL;
     }
   return keyserver;
