@@ -217,7 +217,22 @@ add_file (GpaFileManager *fileman, const gchar *filename)
   gchar *filename_utf8;
 
   /* The tree contains filenames in the UTF-8 encoding.  */
-  filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL),
+  filename_utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
+
+  /* Try to convert from the current locale as fallback. This is important
+     for windows where g_filename_to_utf8 does not take locale into account
+     because the filedialogs already convert to utf8. */
+  if (!filename_utf8)
+    {
+      filename_utf8 = g_locale_to_utf8 (filename, -1, NULL, NULL, NULL);
+    }
+
+  /* Last fallback is guranteed to never be NULL so in doubt we can still fail
+     later showing a filename that can't be found to the user etc.*/
+  if (!filename_utf8)
+    {
+      filename_utf8 = g_filename_display_name (filename);
+    }
 
   store = GTK_LIST_STORE (gtk_tree_view_get_model
                           (GTK_TREE_VIEW (fileman->list_files)));
@@ -559,7 +574,9 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
     "      <menuitem action='WindowsKeyringEditor'/>"
     "      <menuitem action='WindowsFileManager'/>"
     "      <menuitem action='WindowsClipboard'/>"
+#ifdef ENABLE_CARD_MANAGER
     "      <menuitem action='WindowsCardManager'/>"
+#endif
     "    </menu>"
     "    <menu action='Help'>"
 #if 0
@@ -581,7 +598,9 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
     "    <separator/>"
     "    <toolitem action='WindowsKeyringEditor'/>"
     "    <toolitem action='WindowsClipboard'/>"
+#ifdef ENABLE_CARD_MANAGER
     "    <toolitem action='WindowsCardManager'/>"
+#endif
 #if 0
     "    <toolitem action='HelpContents'/>"
 #endif
@@ -622,8 +641,10 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
   /* Fixup the icon theme labels which are too long for the toolbar.  */
   action = gtk_action_group_get_action (action_group, "WindowsKeyringEditor");
   g_object_set (action, "short_label", _("Keyring"), NULL);
+#ifdef ENABLE_CARD_MANAGER
   action = gtk_action_group_get_action (action_group, "WindowsCardManager");
   g_object_set (action, "short_label", _("Card"), NULL);
+#endif
 
   /* Take care of sensitiveness of widgets.  */
   action = gtk_action_group_get_action (action_group, "FileSign");
@@ -650,13 +671,12 @@ static gboolean
 dnd_drop_handler (GtkWidget *widget, GdkDragContext *context,
                   gint x, gint y, guint tim, gpointer user_data)
 {
-  GdkAtom  target_type;
+  GdkAtom target_type = gdk_atom_intern ("text/uri-list", FALSE);
 
   /* If the source offers a target we request the data from her. */
-  if (context->targets)
+  if (context->targets && g_list_find (context->targets,
+                                       GDK_ATOM_TO_POINTER (target_type)))
     {
-      target_type = GDK_POINTER_TO_ATOM
-        (g_list_nth_data (context->targets, DND_TARGET_URI_LIST));
       gtk_drag_get_data (widget, context, target_type, tim);
 
       return TRUE;
@@ -793,8 +813,7 @@ gpa_file_manager_constructor (GType type,
   fileman = GPA_FILE_MANAGER (object);
 
   /* Initialize.  */
-  gtk_window_set_title (GTK_WINDOW (fileman),
-			_("GNU Privacy Assistant - File Manager"));
+  gpa_window_set_title (GTK_WINDOW (fileman), _("File Manager"));
   gtk_window_set_default_size (GTK_WINDOW (fileman), 640, 480);
   /* Realize the window so that we can create pixmaps without warnings.  */
   gtk_widget_realize (GTK_WIDGET (fileman));
