@@ -874,11 +874,82 @@ key_manager_copy (GtkAction *action, gpointer param)
   if (! selection)
     return;
 
-  op = gpa_export_clipboard_operation_new (GTK_WIDGET (self), selection);
+  op = gpa_export_clipboard_operation_new (GTK_WIDGET (self), selection, 0);
   register_operation (self, GPA_OPERATION (op));
 }
 
 
+/* Copy the secret keys into the clipboard.  */
+static void
+key_manager_copy_sec (GtkAction *action, gpointer param)
+{
+  GpaKeyManager *self = param;
+  GList *selection;
+  GpaExportClipboardOperation *op;
+
+  selection = gpa_keylist_get_selected_keys (self->keylist,
+                                             GPGME_PROTOCOL_UNKNOWN);
+  if (!selection || g_list_length (selection) != 1)
+    return;
+
+  op = gpa_export_clipboard_operation_new (GTK_WIDGET (self), selection, 1);
+  register_operation (self, GPA_OPERATION (op));
+}
+
+
+/* Copy the fingerprints of the keys into the clipboard.  */
+static void
+key_manager_copy_fpr (GtkAction *action, gpointer param)
+{
+  GpaKeyManager *self = param;
+  GList *selection, *item;
+  gpgme_protocol_t prot = GPGME_PROTOCOL_UNKNOWN;
+  gpgme_key_t key;
+  char *buffer = NULL;
+  char *p;
+
+  selection = gpa_keylist_get_selected_keys (self->keylist,
+                                             GPGME_PROTOCOL_UNKNOWN);
+  if (!selection)
+    return;
+
+  for (item = selection; item; item = g_list_next (item))
+    {
+      key = (gpgme_key_t)item->data;
+
+      if (prot == GPGME_PROTOCOL_UNKNOWN)
+        prot = key->protocol;
+      else if (prot != key->protocol)
+        {
+          gpa_window_error
+            (_("Only keys of the same procotol may be copied."), NULL);
+          g_free (buffer);
+          buffer = NULL;
+          break;
+        }
+      if (prot == GPGME_PROTOCOL_UNKNOWN)
+        ;
+      else if (!buffer)
+        buffer = g_strconcat (key->subkeys->fpr, "\n", NULL);
+      else
+        {
+          p = g_strconcat (buffer, key->subkeys->fpr, "\n", NULL);
+          g_free (buffer);
+          buffer = p;
+        }
+    }
+  if (buffer)
+    {
+      gtk_clipboard_set_text (gtk_clipboard_get
+                              (GDK_SELECTION_PRIMARY), buffer, -1);
+      gtk_clipboard_set_text (gtk_clipboard_get
+                              (GDK_SELECTION_CLIPBOARD), buffer, -1);
+    }
+
+  g_free (buffer);
+}
+
+
 /* Reload the key list.  */
 static void
 key_manager_refresh (GtkAction *action, gpointer param)
@@ -922,7 +993,8 @@ key_manager_action_new (GpaKeyManager *self,
                         GtkWidget **menu, GtkWidget **toolbar,
                         GtkWidget **popup)
 {
-  static const GtkActionEntry entries[] =
+  static const
+    GtkActionEntry entries[] =
     {
       /* Toplevel.  */
       { "File", NULL, N_("_File"), NULL },
@@ -941,6 +1013,10 @@ key_manager_action_new (GpaKeyManager *self,
       /* Edit menu.  */
       { "EditCopy", GTK_STOCK_COPY, NULL, NULL,
 	N_("Copy the selection"), G_CALLBACK (key_manager_copy) },
+      { "EditCopyFpr", GTK_STOCK_COPY, N_("Copy _Fingerprint"), "<control>F",
+	N_("Copy the fingerprints"), G_CALLBACK (key_manager_copy_fpr) },
+      { "EditCopySec", GTK_STOCK_COPY, N_("Copy Private Key"), NULL,
+	N_("Copy a single private key"), G_CALLBACK (key_manager_copy_sec) },
       { "EditPaste", GTK_STOCK_PASTE, NULL, NULL,
 	N_("Paste the clipboard"), G_CALLBACK (key_manager_paste) },
       { "EditSelectAll", GTK_STOCK_SELECT_ALL, NULL, "<control>A",
@@ -1065,6 +1141,7 @@ key_manager_action_new (GpaKeyManager *self,
 #endif
     "  </toolbar>"
     "  <popup name='PopupMenu'>"
+    "    <menuitem action='EditCopyFpr'/>"
     "    <menuitem action='EditCopy'/>"
     "    <menuitem action='EditPaste'/>"
     "    <menuitem action='KeysDelete'/>"
@@ -1072,6 +1149,7 @@ key_manager_action_new (GpaKeyManager *self,
     "    <menuitem action='KeysSign'/>"
     "    <menuitem action='KeysSetOwnerTrust'/>"
     "    <menuitem action='KeysEditPrivateKey'/>"
+    "    <menuitem action='EditCopySec'/>"
     "    <separator/>"
     "    <menuitem action='KeysExport'/>"
 #ifdef ENABLE_KEYSERVER_SUPPORT
@@ -1143,6 +1221,12 @@ key_manager_action_new (GpaKeyManager *self,
   action = gtk_action_group_get_action (action_group, "EditCopy");
   add_selection_sensitive_action (self, action,
                                   key_manager_has_selection);
+  action = gtk_action_group_get_action (action_group, "EditCopyFpr");
+  add_selection_sensitive_action (self, action,
+                                  key_manager_has_selection);
+  action = gtk_action_group_get_action (action_group, "EditCopySec");
+  add_selection_sensitive_action (self, action,
+                                  key_manager_has_single_selection);
   action = gtk_action_group_get_action (action_group, "KeysDelete");
   add_selection_sensitive_action (self, action,
                                   key_manager_has_selection);
