@@ -18,8 +18,12 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include <glib.h>
 #include <config.h>
+
+#include <glib.h>
+#if GLIB_CHECK_VERSION (2, 6, 0)
+#include <glib/gstdio.h>
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -87,7 +91,7 @@ release_server_list (ServerName list)
 
 
 static int
-read_list (const char *fname)
+read_list (const gchar *fname)
 {
   FILE *fp;
   char line[256], *p;
@@ -98,8 +102,12 @@ read_list (const char *fname)
   if (!fname)
     return -1;
 
+#if GLIB_CHECK_VERSION (2, 6, 0)
+  fp = g_fopen (fname, "r");
+#else
   fp = fopen (fname, "r");
-  if (!fp)       
+#endif
+  if (!fp)
     {
 /*
       fprintf (stderr, "can't open `%s': %s\n", fname, strerror (errno) );
@@ -108,21 +116,21 @@ read_list (const char *fname)
       return -1;
     }
 
-  while ( fgets( line, DIM(line)-1, fp ) ) 
+  while ( fgets( line, DIM(line)-1, fp ) )
     {
       lnr++;
-      if ( *line && line[strlen(line)-1] != '\n' ) 
+      if ( *line && line[strlen(line)-1] != '\n' )
         {
           err = "line too long";
           break;
 	}
-      
+
 
       g_strstrip (line);
       if( !*line || *line == '#' )
         continue; /* comment or empty line */
 
-      for( p=line; *p; p++ ) 
+      for( p=line; *p; p++ )
         {
           if (isspace (*p))
             {
@@ -148,7 +156,7 @@ read_list (const char *fname)
       release_server_list (list);
       return -1;
     }
-  
+
   return 0;
 }
 
@@ -158,7 +166,7 @@ read_list (const char *fname)
  * Returns: 0 = okay.
  */
 int
-keyserver_read_list (const char *confname)
+keyserver_read_list (const gchar *confname)
 {
   int rc;
 
@@ -166,19 +174,16 @@ keyserver_read_list (const char *confname)
 
   if (!serverlist)
     { /* no entries in list - use default values */
-      add_server (&serverlist, "hkp://random.sks.keyserver.penguin.de");
-      add_server (&serverlist, "hkp://blackhole.pca.dfn.de"); 
+      add_server (&serverlist, "hkp://keys.gnupg.net");
+      add_server (&serverlist, "hkp://zimmermann.mayfirst.org");
+      add_server (&serverlist, "hkp://minsky.surfnet.nl");
       add_server (&serverlist, "hkp://pks.gpg.cz");
       add_server (&serverlist, "hkp://pgp.cns.ualberta.ca");
-      add_server (&serverlist, "hkp://minsky.surfnet.nl");
       add_server (&serverlist, "hkp://keyserver.ubuntu.com");
       add_server (&serverlist, "hkp://keyserver.pramberger.at");
 
       add_server (&serverlist, "http://gpg-keyserver.de");
       add_server (&serverlist, "http://keyserver.pramberger.at");
-   
-      add_server (&serverlist, "hkp://subkeys.pgp.net"); 
-      add_server (&serverlist, "ldap://keyserver.pgp.com");
     }
 
   return rc;
